<?php

namespace PACKS\SHIPMENTS\Admin;

use PACKS\SHIPMENTS\Admin\AdminNotice;
use PACKS\SHIPMENTS\Settings;
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

if (!class_exists('\\PACKS\\SHIPMENTS\\Admin\\Getproductinfo')) :


    class Getproductinfo
    {
        protected $apiUser;
        protected $apiUserPassword;
        protected $apiUrl;
        protected $apiAuthUrl;
        protected $orderIds;
        protected $shipments;
        protected $shipmentId;
        protected $_shipmentsData;
        protected $aToken;
        protected $tToken;
        public $continue;
        //protected $orders = array();
        public $responses = array();
        protected $responseMessages = array();
        protected $productoptions = array();
        protected $settings;

        public function __construct()
        {
            $this->settings = new Settings();
            $this->init();
            return $this->productoptions;

        }

        public function init(){

            $this->preprocessData();
            //$this->responseHandler();

        }
        public function preprocessData(){

            $this->senderOptions = get_option('packs_shipments_settings_sender');
            $this->generalOptions = $this->settings->get_common_general_settings();
            $this->apiUser = $this->generalOptions['api_user_name']['default'];
            $this->apiUserPassword = $this->generalOptions['api_user_password']['default'];
            $this->apiUrl = $this->generalOptions['api_getproductinfo_url'];
            $this->apiAuthUrl = $this->generalOptions['api_auth_url'];

            set_time_limit(720000);                 // script timeout: 15 mins.
            ob_start();
            $this->continue = true;
            $this->Authorize();
            $this->processData();
        }

        public function Authorize()
        {

            $postString = "client_id=PacksOnlineApp&client_secret=secret&grant_type=password&scope=PacksOnlineAPI&username=".$this->apiUser."&password=".$this->apiUserPassword;

            // PHP cURL  for https connection with auth
            $ch = curl_init();
            curl_setopt_array($ch, array(
                CURLOPT_URL => "".$this->apiAuthUrl."",
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_ENCODING => "",
                CURLOPT_MAXREDIRS => 10,
                CURLOPT_TIMEOUT => 30,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => "POST",
                CURLOPT_POSTFIELDS => "".$postString."",
                CURLOPT_HTTPHEADER => array(
                    "Cache-Control: no-cache",
                    "Content-Type: application/x-www-form-urlencoded",
                ),
                CURLOPT_SSL_VERIFYPEER => false,
            ));

            $result = curl_exec($ch);

            $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
            curl_close($ch);
            unset($ch);

            if($httpCode == 200){
                $json = json_decode($result);
                $this->tToken = $json->token_type;
                $this->aToken = $json->access_token;
            }else{
                AdminNotice::create()
                    ->error('Api Authorization response is empty')
                    ->show();
            }

            return;
        }

        public function processData()
        {
            $senderData = $this->getSenderData();
            $handler = $senderData['handler'];
            $network = $senderData['network'];
            $i=1;

            try {
                // xml post structure
                $xml_post_array = array(
                    'Handler' => (string)$handler,
                    'Network' => (string)$network
                );

                $xml_post_string = json_encode($xml_post_array);


                // PHP cURL  for https connection with auth
                $ch = curl_init();

                curl_setopt_array($ch, array(
                    CURLOPT_URL => "".$this->apiUrl."",
                    CURLOPT_RETURNTRANSFER => true,
                    CURLOPT_ENCODING => "",
                    CURLOPT_MAXREDIRS => 10,
                    CURLOPT_TIMEOUT => 30,
                    CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                    CURLOPT_CUSTOMREQUEST => "POST",
                    CURLOPT_POSTFIELDS => "".$xml_post_string."",
                    CURLOPT_HTTPHEADER => array(
                        "Accept: application/json",
                        "Authorization: ".$this->tToken." ".$this->aToken,
                        "Content-Type: application/json",
                        "cache-control: no-cache",
                    ),
                    CURLOPT_SSL_VERIFYPEER => false,

                ));

                $response = curl_exec($ch);


                if(empty($response)){
                    $response = curl_error($ch);
                    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
                    curl_close($ch);
                    unset($ch);
                    $this->continue = false;
                    AdminNotice::create()
                        ->error('Api response is empty')
                        ->show();

                }else{

                    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
                    if($httpCode == 404) {
                        $message = "HTTP Error 404. The requested resource is not found. URL";
                        $this->responseMessages['errors'][$i['id']] = $message;
                        return;
                    }
                    if($httpCode == 400) {
                        $message = $response;
                        $this->responseMessages['errors'][$i['id']] = $message;
                        $this->continue = false;
                        return;
                    }
                    if($httpCode == 503) {
                        $message = "HTTP Error 503. The api server is not available";
                        $this->responseMessages['errors'][$i['id']] = $message;
                        $this->continue = false;
                        return;
                    }
                    if (curl_errno($ch)) {
                        $err = curl_error($ch);
                        curl_close($ch);

                        $message = $err;
                        $this->responseMessages['errors'][$i['id']] = $message;

                    }

                    $jsonDecoded = json_decode($response,true);
                    curl_close($ch);
                    unset($ch);

                    $this->responses = $jsonDecoded;
                    $this->productoptions = $this->responses['products'];
                }



            }catch (Exception $e) {
                //Mage::log('time 4.1: ' . time(). ' : '.$e->getMessage(),NULL,'shipmentexport.log');
                //Mage::logException($e);

                // send email
                if($this->sendErrorMail == true){
                    $this->helper->sendErrorMail($e->getMessage(),$this->sendErrorMailTo);
                }
            }



        }

        public function getSenderData(){
            $senderData = array();
            $senderData['handler'] = $this->senderOptions['sender_handler']['default'];
            $senderData['network'] = $this->senderOptions['sender_network']['default'];
            $senderData['country'] = $this->senderOptions['sender_country']['default'];
            $senderData['city'] = $this->senderOptions['sender_city']['default'];
            $senderData['postcode'] = $this->senderOptions['sender_zipcode']['default'];
            $senderData['street'] = $this->senderOptions['sender_street']['default'];
            $senderData['housenumber'] = $this->senderOptions['sender_housenumber']['default'];
            $senderData['name'] = $this->senderOptions['sender_name']['default'];
            return $senderData;
        }

    }

endif;